@@ -1,5 +1,8 @@
 class ApiError(Exception):
-    pass
+    def __init__(self, *args, **kwargs):
+        self.result = kwargs.pop('result', None)
+
+        super(ApiError, self).__init__(*args, **kwargs)
 
 
 class HTTPError(ApiError):
@@ -10,10 +13,7 @@ class HTTPError(ApiError):
 
 
 class MalformedJSONResultError(ApiError):
-    def __init__(self, result=None, *args, **kwargs):
-        super(ApiError, self).__init__(*args, **kwargs)
-
-        self.result = result
+    pass
 
 
 class ModelMappingNotFoundError(ApiError):
@@ -25,10 +25,7 @@ class MiddlewareError(ApiError):
 
 
 class ResultError(ApiError):
-    def __init__(self, result=None, *args, **kwargs):
-        self.result = result
-
-        super(ResultError, self).__init__(*args, **kwargs)
+    pass
 
 
 class ResultDefaultError(ApiError):
@@ -87,4 +84,4 @@ def get_result_error(result, error):
 
     cls = errors.get(error.code, ResultDefaultError)
 
-    return cls(result, error.message)
+    return cls(error.message, result=result)
\ No newline at end of file
